@@ -34,8 +34,9 @@ Usage::
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
     ```
 """
-from typing import Iterator, List
+from typing import Generic, Iterator, List, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
@@ -64,24 +65,34 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class DescribeGlobalNetworksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
     """
 
     def paginate(
         self, *, GlobalNetworkIds: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeGlobalNetworksResponseTypeDef]:
+    ) -> _PageIterator[DescribeGlobalNetworksResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
         """
 
 
 class GetConnectionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
     """
 
@@ -92,16 +103,16 @@ class GetConnectionsPaginator(Boto3Paginator):
         ConnectionIds: List[str] = None,
         DeviceId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetConnectionsResponseTypeDef]:
+    ) -> _PageIterator[GetConnectionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
         """
 
 
 class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
     """
 
@@ -111,16 +122,16 @@ class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         CustomerGatewayArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetCustomerGatewayAssociationsResponseTypeDef]:
+    ) -> _PageIterator[GetCustomerGatewayAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
         """
 
 
 class GetDevicesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
     """
 
@@ -131,16 +142,16 @@ class GetDevicesPaginator(Boto3Paginator):
         DeviceIds: List[str] = None,
         SiteId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetDevicesResponseTypeDef]:
+    ) -> _PageIterator[GetDevicesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
         """
 
 
 class GetLinkAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
     """
 
@@ -151,16 +162,16 @@ class GetLinkAssociationsPaginator(Boto3Paginator):
         DeviceId: str = None,
         LinkId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetLinkAssociationsResponseTypeDef]:
+    ) -> _PageIterator[GetLinkAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
         """
 
 
 class GetLinksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
     """
 
@@ -173,16 +184,16 @@ class GetLinksPaginator(Boto3Paginator):
         Type: str = None,
         Provider: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetLinksResponseTypeDef]:
+    ) -> _PageIterator[GetLinksResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
         """
 
 
 class GetSitesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
     """
 
@@ -192,16 +203,16 @@ class GetSitesPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         SiteIds: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetSitesResponseTypeDef]:
+    ) -> _PageIterator[GetSitesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
         """
 
 
 class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
     """
 
@@ -211,16 +222,16 @@ class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         TransitGatewayConnectPeerArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetTransitGatewayConnectPeerAssociationsResponseTypeDef]:
+    ) -> _PageIterator[GetTransitGatewayConnectPeerAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
         """
 
 
 class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
     """
 
@@ -230,8 +241,8 @@ class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         TransitGatewayArns: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetTransitGatewayRegistrationsResponseTypeDef]:
+    ) -> _PageIterator[GetTransitGatewayRegistrationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.27/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
         """
